@@ -2,7 +2,7 @@ from xml.etree import ElementTree
 
 import requests
 
-from quickbase_json.helpers import FileUpload, Where, QBFile
+from quickbase_json.helpers import FileUpload, Where, QBFile, split_list_into_chunks
 from quickbase_json.qb_insert_update_response import QBInsertResponse
 from quickbase_json.qb_response import QBQueryResponse
 
@@ -212,6 +212,51 @@ class QuickbaseJSONClient:
     Misc.
     """
 
+    def get_choices(self, table: str, fid: int):
+        """
+        Get choices for a given multiple choice field
+        https://developer.quickbase.com/operation/getField
+        :param table: table id
+        :param fid: fid of field to get choices from
+        :return: list of choices from multiple choice field
+        """
+
+        headers = self.headers
+        params = {'tableId': f'{table}', 'fieldId': f'{fid}'}
+        fetch_url = "https://api.quickbase.com/v1/fields/" + str(fid) + "?tableId=" + table + "&includeFieldPerms=False"
+        r = requests.get(fetch_url, headers=headers).json()
+        if not 'message' in r:
+            return r['properties']['choices']
+        else:
+            raise ConnectionError(f'{r["message"]}: {r["description"]}')
+    def multi_query_records(self, table: str, search_field: int, select: list, search_list: list):
+        """
+        Queries for record data.
+        https://developer.quickbase.com/operation/runQuery
+        :param table: quickbase table
+        :param search_field: int, fid of field to search
+        :param select: list, list of FIDs to return for found records
+        :param search_list: list of values to search for
+        :return: json data of records {data: ..., fields: ...}
+        """
+        response_for_return = {'data': [], 'fields': [],
+                               'metadata': {'numFields': 0, 'numRecords': 0, 'skip': 0, 'totalRecords': 0}}
+        list_of_searches = split_list_into_chunks(array=search_list, chunk_size=10)
+        for list_of_100 in list_of_searches:
+            query = Where(fid=search_field, operator='EX', value=list_of_100).build(join='OR')
+            r = self.query_records(table=table, select=select, where=query)
+            if r.ok and r.status_code == 200:
+                response_for_return['data'].extend(r['data'])
+                response_for_return['fields'] = r['fields']
+                response_for_return['metadata']['numFields'] = r['metadata']['numFields']
+                response_for_return['metadata']['numRecords'] += r['metadata']['numRecords']
+                response_for_return['metadata']['skip'] += r['metadata']['skip']
+                response_for_return['metadata']['totalRecords'] += r['metadata']['totalRecords']
+            else:
+                raise ConnectionError(f'{r.status_code}: {r.text}')
+        return response_for_return
+
+
     def __str__(self):
         """
         Shows a string representation of a QuickbaseJSONClient.
